/*
 * Copyright (C) 2011 Giuseppe Calà <jiveaxe@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "configwidget.h"

#include <QDesktopServices>
#include <QDebug>

ConfigWidget::ConfigWidget( KConfigDialog *parent )
{
    config = new QWidget( this );
    steamcompanionUi.setupUi( config );

    steamcompanionUi.intervalSpinBox->setSuffix(ki18np(" hour"," hours"));

    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("čeština"),"czech");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Dansk"),"danish");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Nederlands"),"dutch");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("English"),"english");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Suomi"),"finnish");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Français"),"french");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Deutsch"),"german");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("magyar"),"hungarian");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Italiano"),"italian");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("日本語"),"japanese");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("한국어"),"koreana");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Norsk"),"norwegian");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Polski"),"polish");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Português"),"portuguese");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Русский"),"russian");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Română"),"romanian");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("简体中文"),"schinese");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Español"),"spanish");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Svenska"),"swedish");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("繁體中文"),"tchinese");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("ไทย"),"thai");
    steamcompanionUi.languageComboBox->addItem(QString::fromUtf8("Türkçe"),"turkish");

    connect(steamcompanionUi.intervalSpinBox , SIGNAL(valueChanged(int)), this , SIGNAL(enableApply()));
    connect(steamcompanionUi.languageComboBox , SIGNAL(activated(int)), this , SIGNAL(enableApply()));
    connect(steamcompanionUi.steamIdLineEdit , SIGNAL(textEdited(QString)), this , SIGNAL(enableApply()));
    connect(steamcompanionUi.idFinderUrl , SIGNAL(leftClickedUrl(const QString&)), SLOT(urlLabelClicked(const QString&)));
    connect(steamcompanionUi.scrollbarsCheckBox , SIGNAL(stateChanged(int)), this , SIGNAL(enableApply()));
}

ConfigWidget::~ConfigWidget()
{

}

void ConfigWidget::setCurrentLanguage( QString language )
{
    steamcompanionUi.languageComboBox->setCurrentIndex(steamcompanionUi.languageComboBox->findData(language));
}

QString ConfigWidget::currentLanguage() const
{
    return steamcompanionUi.languageComboBox->itemData(steamcompanionUi.languageComboBox->currentIndex(), Qt::UserRole).toString();
}

void ConfigWidget::setUpdateInterval( uint interval )
{
    steamcompanionUi.intervalSpinBox->setValue( interval );
}

uint ConfigWidget::updateInterval() const
{
    return steamcompanionUi.intervalSpinBox->value();
}

void ConfigWidget::setSteamId( QString steamId )
{
    steamcompanionUi.steamIdLineEdit->setText( steamId );
}

QString ConfigWidget::steamId() const
{
    return steamcompanionUi.steamIdLineEdit->text();
}

void ConfigWidget::setShowScrollbars( bool showScrollBars )
{
    steamcompanionUi.scrollbarsCheckBox->setChecked(showScrollBars);
}

bool ConfigWidget::showScrollBars() const
{
    return steamcompanionUi.scrollbarsCheckBox->isChecked();
}

void ConfigWidget::urlLabelClicked(const QString& url)
{
    QDesktopServices::openUrl(QUrl(url, QUrl::TolerantMode));
}
