/*
 * Copyright (C) 2011 Giuseppe Calà <jiveaxe@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef STEAMCOMPANION_HEADER
#define STEAMCOMPANION_HEADER

#include <Plasma/PopupApplet>
#include <Solid/Networking>
#include "ui_config.h"


namespace Plasma {
    class TabBar;
}

class QGraphicsLinearLayout;
class QNetworkCookieJar;
class QWebPage;
class DealsWidget;
class LibraryWidget;
class ConfigWidget;


class SteamCompanion : public Plasma::PopupApplet
{
    Q_OBJECT
    public:
        SteamCompanion(QObject *parent, const QVariantList &args);
        ~SteamCompanion();

        QGraphicsWidget *graphicsWidget();

    public Q_SLOTS:
        void loadSpecialsPageFinished();
        void loadSpotlightPageFinished();
        void loadLibraryPageFinished();
        void startFetch();
        void doNetworkActivity();

    protected:
        virtual void createConfigurationInterface(KConfigDialog *parent);
        virtual void keyPressEvent ( QKeyEvent * event );

    protected Q_SLOTS:
        void applyConfig();
        void makeStylesheet();

    private Q_SLOTS:
        void networkStatusChanged(Solid::Networking::Status newstatus);

    public slots:
        void configChanged();

    private:
        ConfigWidget *mConfigWidget;

        uint m_interval;
        uint m_currPage;
        uint m_serverTime;
        uint m_serverEndTime;
        bool m_hasNext;
        bool m_hasSpotlight;
        bool m_hasDailyDeal;
        QString m_gamesArray;
        QString m_filterText;

        QString m_language;
        QString m_cssDir;
        QString m_jsPrototype;
        QString m_steamID;
	bool m_showScrollBars;

        QTimer *m_timer;

        QGraphicsLinearLayout* m_layout;
        QGraphicsWidget *m_graphicsWidget;
        Plasma::TabBar *m_tabBar;
        DealsWidget *m_dealsWidget;
        LibraryWidget *m_libraryWidget;

        QNetworkCookieJar *m_jar;
        QWebPage *m_homePage;
        QWebPage *m_specialsPage;
        QWebPage *m_libraryPage;

        struct Game {
            uint gameId;
            QString title;
            QString description;
            QString release;
            int metascore;
            QString originalPrice;
            QString finalPrice;
            QString discount;
            QString img;
            QString link;
        };

        QList<Game *> m_specials;
        QList<Game *> m_spotlights;
        QList<Game *> m_ownedgames;
        Game m_dailydeal;
        
        void populateWebView();
        void populateLibraryView();
        void populateEmptyLibraryView();

        QVector<uint> m_oldSpecials;
        QVector<uint> m_newSpecials;

        Solid::Networking::Status m_current_state;
	
	void tabBarHandler();
};

K_EXPORT_PLASMA_APPLET(steamcompanion, SteamCompanion)

#endif
